@@ -33,7 +33,7 @@ use Perl6::Export::Attrs;
 use Encode qw(decode_utf8);
 use utf8;
 
-our $VERSION = '2.3.22';
+our $VERSION = '2.3.23';
 
 my $q = new CGI;
 
@@ -371,7 +371,7 @@ Ftree - family tree generator
 
 =head1 EXAMPLE 
 
-L<https://still-lowlands-7377.herokuapp.com/ftree?type=tree;target=Abraham_Simpson;levels=2;passwd=;lang=gb>
+L<https://still-lowlands-7377.herokuapp.com>
 
 =head1 SYNOPSIS
   
